const co = require('co')
const { start: startInflux, metric } = require('@pluralsight/videoservices-influx')
const { getMachineState } = require('./state')

const startSystemMetrics = co.wrap(function * ({team, service, server}) {
  yield startInflux(
    team,
    service,
    server,
    (r) => { },
    6 * 1000
  )

  const makeMeasurement = (team, service, ip) => (measurement, value, xTags = {}) => {
    const tags = Object.assign({ ip, team, service }, xTags)
    const fields = { value }

    console.log('makeMeasurement', { measurement, tags, fields })
    return { measurement, tags, fields }
  }

  const makeCpuMeasurement = (team, service, ip, measurement) => (value, index) => {
    const cpuIndex = `cpu_${index}`
    const xTags = { cpuIndex }
    const measure = makeMeasurement(team, service, ip)

    return measure(measurement, value, xTags)
  }

  setInterval(co.wrap(function * () {
    const state = yield getMachineState()
    const measure = makeMeasurement(team, service, state.ip)
    const measureCpu = makeCpuMeasurement(team, service, state.ip, 'cpu')

    let measurements = []
    measurements.push(measure('processLoad', state['processLoad']))
    measurements.push(measure('diskFree', state['diskFree']))
    measurements.push(measure('uptime', state['uptime']))
    measurements.push(measure('percentageMemUsed', state['percentageMemUsed']))
    measurements = measurements.concat(state.cpuLoads.map(measureCpu))

    measurements.map(m => metric(m.measurement, m.tags, m.fields))
  }), 5 * 1000)
})

module.exports = {
  startSystemMetrics
}
