const systemInfo = require('systeminformation')
const diskSpace = require('diskspace')
const co = require('co')
const uuid = require('uuid')
const { address } = require('ip')
const os = require('os')

const guid = uuid.v4()
const pid = process.pid
const version = process.env.npm_package_version || '0000'
const appName = process.env.npm_package_name || 'no_name'

let throughput = 0
const ip = address()

const getDiskSpace = () => {
  return new Promise((resolve, reject) => {
    diskSpace.check('/', (err, total, free, status) => {
      if (err) reject(err)
      else resolve(free)
    })
  })
}

const getMemAndCpu = co.wrap(function * () {
  const load = yield systemInfo.currentLoad()
  const cpuLoads = load.cpus.map(cpu => Math.floor(cpu.load))

  const ps = yield systemInfo.processes()
  const process = ps.list.filter((p) => p.pid === pid)[0]
  const processLoad = Math.floor(process.pcpu)
  const mem = Math.floor(process.pmem)
  const percentageMemUsed = Math.floor(((os.totalmem() - os.freemem()) / os.totalmem()) * 100)
  return {cpuLoads, processLoad, mem, percentageMemUsed}
})

const getMachineState = co.wrap(function * () {
  const diskFree = yield getDiskSpace()
  const {cpuLoads, processLoad, mem, percentageMemUsed} = yield getMemAndCpu()
  const result = {
    ip,
    cpuLoads,
    mem,
    percentageMemUsed,
    processLoad,
    diskFree,
    guid,
    version,
    appName,
    throughput,
    timestamp: Date.now(),
    uptime: Math.floor(process.uptime()).toString()
  }
  throughput = 0
  return result
})

module.exports = {
  getMachineState
}
