const assert = require('assert')
const equal = assert.deepEqual
const co = require('co')
const { getMachineState } = require('./state')

describe('state.js', function () {
  describe('#getMachineState()', function () {
    it('should get the cpu, mem, disk', co.wrap(function * () {
      const result = yield getMachineState()
      equal(Array.isArray(result.cpuLoads), true, 'lacks cpuLoads')
      result.cpuLoads.forEach((cpuLoad) => {
        equal(Number.isInteger(cpuLoad), true, 'cpuLoad is not a number')
      })
      equal(Number.isInteger(result.processLoad), true, 'lacks processLoad')
      equal(Number.isInteger(result.mem), true, 'lacks mem')
      equal(Number.isInteger(result.percentageMemUsed), true, 'lacks percentageMemUsed')
      equal(Number.isInteger(result.diskFree), true, 'lacks diskFree')
      equal(typeof result.uptime, 'string', 'lacks uptime')
      equal(isIp(result.ip), true, 'need ip address')
    }))
  })
})

function isIp (ipaddress) {
  if (/^(25[0-5]|2[0-4][0-9]|[01]?[0-9][0-9]?)\.(25[0-5]|2[0-4][0-9]|[01]?[0-9][0-9]?)\.(25[0-5]|2[0-4][0-9]|[01]?[0-9][0-9]?)\.(25[0-5]|2[0-4][0-9]|[01]?[0-9][0-9]?)$/.test(ipaddress)) {
    return true
  }
  return false
}
